package com.tuoheng.task.controller;

import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.task.entity.Equipment;
import com.tuoheng.task.query.EquipmentQuery;
import com.tuoheng.task.service.IEquipmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 飞行设备表 前端控制器
 *
 * @author WangHaoran
 * @since 2022-06-29
 */
@RestController
@RequestMapping("/equipment")
public class EquipmentController {

    @Autowired
    private IEquipmentService equipmentService;

    /**
     * 获取飞行设备分页列表
     *
     * @param equipmentQuery 查询条件
     * @return
     */
    @GetMapping("/index")
    public JsonResult index(EquipmentQuery equipmentQuery) {
        return equipmentService.getList(equipmentQuery);
    }

    /**
     * 添加飞行设备
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("/add")
    public JsonResult add(@RequestBody Equipment entity) {
        return equipmentService.add(entity);
    }

    /**
     * 更新飞行设备
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("/edit")
    public JsonResult edit(@RequestBody Equipment entity) {
        return equipmentService.edit(entity);
    }

    /**
     * 删除飞行设备
     *
     * @param equipmentId 飞行设备ID
     * @return
     */
    @DeleteMapping("/delete/{equipmentId}")
    public JsonResult delete(@PathVariable("equipmentId") String equipmentId) {
        return equipmentService.deleteById(equipmentId);
    }

}
