package com.tuoheng.task.controller;

import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.task.entity.EquipmentMount;
import com.tuoheng.task.query.EquipmentMountQuery;
import com.tuoheng.task.service.IEquipmentMountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 挂载设备表 前端控制器
 *
 * @author WangHaoran
 * @since 2022-06-29
 */
@RestController
@RequestMapping("/equipmentMount")
public class EquipmentMountController {

    @Autowired
    private IEquipmentMountService equipmentMountService;

    /**
     * 获取挂载设备分页列表
     *
     * @param equipmentMountQuery 查询条件
     * @return
     */
    @GetMapping("/index")
    public JsonResult index(EquipmentMountQuery equipmentMountQuery) {
        return equipmentMountService.getList(equipmentMountQuery);
    }

    /**
     * 添加挂载设备
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("/add")
    public JsonResult add(@RequestBody EquipmentMount entity) {
        return equipmentMountService.add(entity);
    }

    /**
     * 更新挂载设备
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("/edit")
    public JsonResult edit(@RequestBody EquipmentMount entity) {
        return equipmentMountService.edit(entity);
    }

    /**
     * 删除挂载设备
     *
     * @param equipmentMountId 挂载设备ID
     * @return
     */
    @DeleteMapping("/delete/{equipmentMountId}")
    public JsonResult delete(@PathVariable("equipmentMountId") String equipmentMountId) {
        return equipmentMountService.deleteById(equipmentMountId);
    }
}
