package com.tuoheng.task.controller;

import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.task.entity.Stream;
import com.tuoheng.task.query.StreamQuery;
import com.tuoheng.task.service.IStreamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 河流表 前端控制器
 *
 * @author WangHaoran
 * @since 2022-06-29
 */
@RestController
@RequestMapping("/stream")
public class StreamController {

    @Autowired
    private IStreamService streamService;

    /**
     * 获取河流分页列表
     *
     * @param streamQuery 查询条件
     * @return
     */
    @GetMapping("/index")
    public JsonResult index(StreamQuery streamQuery) {
        return streamService.getList(streamQuery);
    }

    /**
     * 添加河流
     *
     * @param entity 实体对象
     * @return
     */
    @PostMapping("/add")
    public JsonResult add(@RequestBody Stream entity) {
        return streamService.add(entity);
    }

    /**
     * 更新河流
     *
     * @param entity 实体对象
     * @return
     */
    @PutMapping("/edit")
    public JsonResult edit(@RequestBody Stream entity) {
        return streamService.edit(entity);
    }

    /**
     * 删除河流
     *
     * @param streamId 河流ID
     * @return
     */
    @DeleteMapping("/delete/{streamId}")
    public JsonResult delete(@PathVariable("streamId") String streamId) {
        return streamService.deleteById(streamId);
    }
}
